==> services-core-1.2.0.tgz: package/lib/sdk.js <==
import axios from "axios";
/**
 * Reserve account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function reserveAccount(query, baseUrl = "http://services-core") {
    const response = await axios.post(`${baseUrl}/api/accounts/reservation`, null, { params: query });
    return response.data;
}
/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function createAccount(query, data, baseUrl = "http://services-core") {
    const response = await axios.post(`${baseUrl}/api/accounts`, data, { params: query });
    return response.data;
}
/**
 * Update contact information
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function updateContactInformation(query, data, baseUrl = "http://services-core") {
    const response = await axios.post(`${baseUrl}/api/contacts`, data, { params: query });
    return response.data;
}
/**
 * Get interest rates
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getInterestRates(query, baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/information/interest-rates`, { params: query });
    return response.data;
}
/**
 * Get loan to value
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getLoanToValue(query, baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/information/loan-to-value`, { params: query });
    return response.data;
}
/**
 * Get account list
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getAccountList(baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/accounts`);
    return response.data;
}
/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getAccountById(baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/accounts/:accountNo/?${process.env.COUNTRY_ID}&${process.env.BUSINESS_AREA_ID}`);
    return response.data;
}
/**
 * Get transactions
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getTransactions(query, baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/accounts/:accountNo/transactions`, { params: query });
    return response.data;
}
/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getContactInformation(query, baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/contacts/legal-id/NO17059896083`, { params: query });
    return response.data;
}

==> services-core-1.2.6.tgz: package/lib/sdk.js <==
import axios from "axios";
/**
 * Reserve account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function reserveAccount(query, baseUrl = "http://services-core") {
    const response = await axios.post(`${baseUrl}/api/accounts/reservation`, null, { params: query });
    return response.data;
}
/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function createAccount(data, baseUrl = "http://services-core") {
    const response = await axios.post(`${baseUrl}/api/accounts`, data);
    return response.data;
}
/**
 * Update contact information
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function updateContactInformation(query, data, baseUrl = "http://services-core") {
    const response = await axios.post(`${baseUrl}/api/contacts`, data, { params: query });
    return response.data;
}
/**
 * Get interest rates
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getInterestRates(query, baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/information/interest-rates`, { params: query });
    return response.data;
}
/**
 * Get loan to value
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getLoanToValue(query, baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/information/loan-to-value`, { params: query });
    return response.data;
}
/**
 * Get account list
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getAccountList(baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/accounts`);
    return response.data;
}
/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getAccountById(baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/accounts/:accountNo/?${process.env.COUNTRY_ID}&${process.env.BUSINESS_AREA_ID}`);
    return response.data;
}
/**
 * Get transactions
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getTransactions(query, baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/accounts/:accountNo/transactions`, { params: query });
    return response.data;
}
/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getContactInformation(query, baseUrl = "http://services-core") {
    const response = await axios.get(`${baseUrl}/api/contacts/legal-id/NO17059896083`, { params: query });
    return response.data;
}
